// RTCのEEPROMのサンプルスケッチ
// SW3ボタンを押すと、A0をサンプリングしてEEPROMに書き込み
// 全領域に書き込んでシリアルモニタに表示する

#include <BiZduino.h>
#include <BiZduinoRTC.h>

#define SAMPLING_TIME 50  // サンプリング間隔

BiZduinoLED3 LED3;  // LED3インスタンス
BiZduinoSW3 SW3;    // SW3インスタンス

void setup() {
  // シリアルモニタとの通信を開始
  Serial.begin(115200);
  RTC.begin();

  // EEPROM全領域表示
  readAll();
}

void loop() {

  // SW3が押された時か判定
  if (SW3.isClicked()) {

    // LED3点灯
    LED3.on();

    Serial.println("Sampling start");

    // サンプリング開始
    for (int pos = 0 ; pos < 512 ; pos++) {
      unsigned long time = millis();

      int data = analogRead(0) / 4; // A0の値を0～255にする

      // EEPROMに書き込み
      if (!RTC.writeEEPROM(pos, data)) {
        Serial.println();
        Serial.println("EEPROM write error.");
      }

      // 16バイト毎にピリオド表示
      if (pos % 16 == 15)
        Serial.write('.');

      unsigned long elapsed = millis() - time;  // 経過時間

      // サンプリング間隔まで待つ
      if (elapsed < SAMPLING_TIME)
        delay(SAMPLING_TIME - elapsed);
    }
    Serial.println();

    // LED3消灯
    LED3.off();

    // EEPROM全領域表示
    readAll();

  }

  delay(50);
}

// RTC EEPROM 全領域を読取り表示
boolean readAll() {
  for (int pos = 0; pos < 512; pos++) {
    uint8_t data = RTC.readEEPROM(pos);

    if (pos % 16 == 0) {
      print2hex(pos / 16);
      Serial.print("0 :");
    }
    Serial.write(' ');
    print2hex(data);
    if (pos % 16 == 15) {
      Serial.println();
    }
  }
  return true;
}

// 2桁16進表示
void print2hex(uint8_t number) {
  if (number < 16) {
    Serial.write('0');
  }
  Serial.print(number, 16);
}
